@@ -2,8 +2,12 @@
 
 //! A lending program for the Solana blockchain.
 
-pub mod instruction;
+pub use crate::instruction::{
+    deposit_obligation_collateral,
+    redeem_reserve_collateral
+};
 
+mod instruction;
 mod entrypoint;
 mod error;
 mod math;
